@@ -17,7 +17,7 @@
 # ============================================================================
 # Name        : mfefolders.py
 # Author      : thavoc@gmail.com
-# Version     : 0.22
+# Version     : 0.23
 # Description : Toggles MfE sync by folders and renames local folders
 # ============================================================================
 
@@ -25,10 +25,10 @@ import gtk
 import hildon
 import sqlite3
 import gconf
-import osso
+#import osso
 import sys
 
-ctVersion = "V0.22"
+ctVersion = "V0.23"
 folders = []
 checkbuttons = []
 entries = []
@@ -38,13 +38,11 @@ def toggle(widget, data):
     global conn
     global c
     if widget.get_active():
-#        print checkbuttons[data].get_label(), "activated"
-        c.execute("update mailfoldercustom set value=1 where name='Class' and id in (select id from mailfolders where name='" + checkbuttons[data].get_label() + "')")
+        c.execute("update mailfoldercustom set value=1 where name='Class' and id=" + str(folders[data][2]))
         conn.commit()
         hildon.hildon_banner_show_information(widget, "", str(checkbuttons[data].get_label()) + " activated")
     else:
-#        print checkbuttons[data].get_label(), "deactivated"
-        c.execute("update mailfoldercustom set value=9 where name='Class' and id in (select id from mailfolders where name='" + checkbuttons[data].get_label() + "')")
+        c.execute("update mailfoldercustom set value=9 where name='Class' and id=" + str(folders[data][2]))
         conn.commit()
         hildon.hildon_banner_show_information(widget, "", str(checkbuttons[data].get_label()) + " deactivated")
 
@@ -52,7 +50,7 @@ def save(widget, data):
     global conn
     global c
 #    print "Updating", folders[data][0],  "to", folders[data][1]
-    c.execute("update mailfolders set displayname='" + folders[data][1] + "' where displayname='" + folders[data][0] + "'")
+    c.execute("update mailfolders set displayname='" + folders[data][1] + "' where id=" + str(folders[data][2]))
     conn.commit()
     hildon.hildon_banner_show_information(widget, "", "Updating "+str(folders[data][0])+" to "+str(folders[data][1]))
     folders[data][0] = folders[data][1]
@@ -71,7 +69,7 @@ def main():
     global folders
     global conn
     global c
-    osso_c = osso.Context("mfefolders", "0.2.1", False)
+#    osso_c = osso.Context("mfefolders", "0.2.1", False)
     program = hildon.Program.get_instance()
     mainwin = hildon.Window()
     mainwin.set_markup("MfEfolders <small>" + ctVersion + "</small>")
@@ -83,7 +81,7 @@ def main():
         note = hildon.hildon_note_new_information(mainwin, "ActiveSync account not found!\n exiting...")
         response = gtk.Dialog.run(note)
         note.destroy()
-        sys.exit()
+#        sys.exit()
 #
     note = gtk.Dialog("",mainwin,gtk.DIALOG_MODAL, ("Continue", gtk.RESPONSE_YES, "Exit", gtk.RESPONSE_NO) )
     lbl = gtk.Label("Please close the mail client if it's open\n and make sure MfE is not synching ...")
@@ -103,7 +101,7 @@ def main():
     c.execute("select f.id,f.name,f.displayname,c.value from mailfolders as f join mailfoldercustom as c on f.id=c.id where c.name='Class' and c.value in ('1','9')")
     for row in c:
 #        print row
-        folders.append([row[2], ""])
+        folders.append([row[2], "", row[0]])
         button = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT) 
         button.set_label(row[1])
         if row[3]=='1': button.set_active(1)
